(* $Id: godi_concmd.mli 953 2011-09-02 21:28:08Z gerd $ *)

(** Console commands

    Console commands are control messages sent from a running process
    to the godi_console UI

 *)

type concmd =
    [ `Prompt of string * string
    | `Password_prompt of string * string
    ]
  (** Commands:
      - [`Prompt(prompt,file)]: Prompts for one line of input. The string
        [prompt] is displayed to get the user's attention. The line is
        written to the [file]
      - [`Password_prompt(prompt,file)]: Same, but the typed input is
        hidden

      Win32: The [file] names must be native Win32 names.
   *)

val have_console : unit -> bool
  (** Whether the console is present. This is indicated by the environment
      variable GODI_CONSOLE_TTY=godi
   *)

val string_of_concmd : concmd -> string
  (** Returns the control message as string to be added to the output *)

type token =
    [ concmd
    | `Data of string
    | `Incomplete
    ]

val scan : Netbuffer.t -> bool -> token
  (** Checks whether the start of the buffer is a command, and returns
      a token. The token is either the command, or data. The scanned
      part of the buffer is deleted.

      If the buffer contains the beginning of a command, [`Incomplete]
      is returned.

      The bool arg indicates whether the end of the data stream is reached.
      If so, even beginnings of commands are returned as [`Data].
   *)

val send_data : string -> string -> unit
  (** [send_data file data] *)

val receive_data : string -> string
  (** [receive_data file] *)
